//
//      chinpi.cpp - Compute pi by the Chinese method,
//			integrating 4.0*sqrt(1 - y**2)
//			in the first quadrant of the
//			unit circle from 0 to 1, which gives pi
//			as 4 times the area of the quadrant.
//			Fix pi between upper and lower sums.
//
//                      - Author: James A. Green.
//
//
#include <stdio.h>
#include <math.h>
#include <string.h>
#include <stdlib.h>
main()
{
	double pi0 = 3.141592653589793;  //the known value of pi.
	double xlow;     	// low sum starts with y(delta).
	double xcent;		// center sum starts with y(delta/2.0).
	double xhi;		// high sum starts with y(0).
//			   	   Note y = sqrt(1.0 - x*x);
        double delta;  		// delta = x/N.
	double lowsum;  	// lower sum.
        double centsum;	// sum on center of interval
        double hisum;   // upper sum.  lowsum < pi < highsum.
	double pi;      // the computed value of pi from our algorithm.
	int i;          // the counter i and the number of steps n.
	int n;          // the number of steps n in finding pi.
	int more = 1;

     while(more == 1){
	printf("Chinpi - Compute pi by the ancient Chinese method:\n");
	printf("         Fix it between upper and lower sums of N \n");
	printf("         steps per sum, integrating the function\n");
	printf("         f = 4.0*y = 4.0*sqrt(1.0 - x*x) along the\n");
	printf("         x-axis from 0 to 1.\n\n");
	printf("Enter N < 32001, the number of steps along the x-axis:");
	scanf("%d",&n);
	printf("\n");
	if(n == 0 || n == 1 || n < 0){
	   printf("The minimum number of steps is 2.\n");
	   exit(0);
	}
	delta = 1.000000000000000/n;
	xhi = 0.0;	  // take x in the interval center.
        hisum = 0.0;
	xlow = 1.99*(delta/2.0); //take xlow near end to avoid neg error.
	lowsum = 0.0;
	xcent = delta/2.0;
        centsum = 0.0;
	for(i = 0; i < n ; i++){        
	    hisum = hisum + 4.0*(sqrt( 1.0 - xhi*xhi ))*delta;
	    xhi = xhi + delta;	// point into next interval.
	    lowsum = lowsum + 4.0*(sqrt( 1.0 - xlow*xlow ))*delta;
	    xlow = xlow + delta;
	    centsum = centsum + 4.0*(sqrt(1.0 - xcent*xcent))*delta;
	    xcent = xcent + delta;
	}
	printf("For N=%d, pi is about %1.15f = centersum\n", n, centsum);
	printf("lowsum = %1.10f < pi < %1.10f = highsum\n\n", lowsum, hisum);
	printf("Pi is known = 3.141592653589793...\n\n");

     	printf("Enter 1 to continue or 0 to exit:");
	scanf("%d", &more);
	printf("\n");
	if(more == 0) exit;
     }
     printf("End Chinpi, Calculation of pi via Integration\n");
     printf("            in the first quadrant of the unit circle.\n\n");

}



































































































































































































































































































































































































































































































