//
//      newton.cpp - Compute pi by the Newtonian method,
//                   from a series expansion for the arcsine.
//
//      We use (1 - x)**(-n) = 1 + nx + [n(n+1)/2!]x**2
//					+ [n(n+1)(n+2)/3!]x**3
//			+...+ [n(n+1)(n+2)..(n+m)/(m+1)!]x**m+1  +...
//
// Then we set x = x**2  and  -n = -1/2 to obtain an easily integrable
//  series expression for arcsin(x):
//
//  (1 - x**2)**(-1/2) = 1 + [(1/2)/1!]x**2 + [(1/2)(1/2 + 1)/2!]x**4
//                     + [(1/2)(1+1/2)(2+1/2)/3!]x**6
//	      +..+[(1/2)(1+1/2)(2+1/2)...(m + 1/2)/(m+1)!]x**(2m+2) +..
//
// Arcsin(x) is just the integral of the above expression,
//  term-by-term, so that
//
// Arcsin(x) = x + ([(1/2)/1!]x**3)/3 + ([(1/2)(1+1/2)/2!]x**5)/5
//             + ([(1/2)(1+1/2)(2+1/2)/3!]x**7)/7
//     +..+ ([(1/2)(1+1/2)(2+1/2)..(m + 1/2)/(m+1)!]x**(2m+3))/(2m+3)
//     +....
// 		  
//  We use Arcsin(1/2) = pi/6 to compute pi:
//
//   pi = 6 Arcsin(1/2) = 6[ (1/2) + [(1/2)/1!]((1/2)**3)/3
//                          + [(1/2)(1+1/2)/2!]((1/2)**5)/5
//                          + [(1/2)(1+1/2)(2+1/2)/3!]((1/2)**7)/7
//  + [(1/2)(1+1/2)(2+1/2)...(m+1/2)/(m+1)!]((1/2)**(2m+3))/(2m+3) +..]
//
//  This has the form  3 + m=0_term + m=1_term + m=2_term
//                          + m=m_term +...
//
// The program computes  3 + Sum[thru N]of(m=m_term)starting with m=0.
//                      
//                      - Author: James A. Green, who derived the
//					expression for the mth term.
//			- Compiler: Borland C/C++
//
//
#include <stdio.h>
#include <math.h>
#include <string.h>
#include <stdlib.h>
main()
{
	double pi0 = 3.141592653589793;
//the known value of pi.
	double plow;        // plow = 2**(n+2).
	double pival; // computed pi value = 3 + term(0) + term(1) +..

	double term(int m); // mth term in series expansion for pi.
	double termx;
	int n;		// index of the last term in the pi expansion.
	int more = 1;
	int i;

     while(more == 1){
	printf("Newton - Compute pi by the Newtonian method:\n");
	printf("  Uses arcsin(1/2) = pi/6 with a series expansion \n");
	printf("  for arcsin(1/2), so that\n");
	printf("  pi = 6 arcsin(1/2) = 3 + Sum(thru N)of(m_term,\n");
	printf("       starting with the m=0 term and terminating\n");
	printf("       with the m=N term. pi = 3 + (N+1)terms.\n");
	printf("      \n");
	printf("      \n");  
	printf("Enter N < 100, to compute 3 + m=0_term +..+ m=N_term:");
	scanf("%d",&n);
	printf("\n");
	if(n < 0){
	   printf("N may not be less than zero.");
	   exit(0);
	}

	pival = 3.0;	// 3 is the root for pi expansion.
        printf("pi = 3.0 \n");
	for(i=0; i <= n; i++){
        	termx = term(i);
		printf(" + term[%d] = %1.30f\n",i, termx);
		pival = pival + termx;
                printf("  PI_value[thru term %d] = %1.30f\n",i, pival);
	}
	printf("Known pi = %1.15f \n",pi0);

     	printf("Enter 1 to continue or 0 to exit:");
	scanf("%d", &more);
	printf("\n");
	if(more == 0) exit;
     }
     printf("End Newton, Calculation of pi via the method of\n");
     printf("            Sir Isaac Newton.\n\n");

}
//
// term(m) =
//
//    6*[(1/2)(1+1/2)(2+1/2)...(m+1/2)/(m+1)!]((1/2)**(2m+3))/(2m+3).
//
double term(int m)
{
	int i;
	double termv;
	double factorial( int k);
	double mproduct( int k );
        double powerhalf( int k );
	double m2p3;

	m2p3 = (2*m) + 3;	
	termv = 6.0*(mproduct(m)/factorial(m + 1))*(powerhalf(2*m+3)/m2p3);
	
        return(termv);
}
double mproduct( int k )
{
	double v;
	int i;
        double ri;
        v = 1.00;
	for( i = 0; i <= k; i++){
		ri = i;
		v = v*( 0.5 + ri);                
	}
        return(v);
}
double factorial(int k)
{
	int i;
	double x;
        x = 1.0;
	for(i = 1; i <= k; i++){
	   x = x*i;
	} 
	return(x);
}
double powerhalf( int k )
{
	int i;
	double v2;
	v2 = 1.00;
	if( k == 0 ) return( 1.0 );

	for( i=1; i <= k; i++){
             v2 = v2*0.5;
	}
        return( v2 );
}



































































































































































































































































































































































































































































































